<?php

namespace Onestartup\Blog\Controller;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Yajra\Datatables\Datatables;
use Onestartup\Blog\Model\EntryCategory as Category;
use Onestartup\Blog\Model\EntryTag as TagCatalog;
use Onestartup\Blog\Model\Entry;
use Onestartup\Blog\Model\CommentPost;

class BlogController extends Controller
{
    public function index(Request $request)
    {
        if(isset($request->category)){
            $category = Category::where('slug', $request->category)->first();
            $posts = $category->entries()->where('status',1)->orderBy('publication_date', 'desc')->paginate(config("blog.blog-index.post-pagination"));
        } elseif (isset($request->tags)) {
            $tags = explode(",", $request->tags);
            $posts = Entry::where('status',1)->where(function ($query) use($tags) {
                for ($i = 0; $i < count($tags); $i++){
                    $query->orwhere('tags', 'like',  '%' . $tags[$i] .'%');
                }      
            })->orderBy('publication_date', 'desc')->paginate(config("blog.blog-index.post-pagination"));
           
        } else {
            $posts = Entry::where('status',1)->orderBy('publication_date', 'desc')->paginate(config("blog.blog-index.post-pagination"));
        }
        $otros = Entry::where('status',1)->inRandomOrder()->take(config("blog.blog-index.otros"))->get();
        $categories = Category::where('active', 1)->get();
        
        return view('blog-public::list')
            ->with('categories', $categories)
            ->with('otros', $otros)
            ->with('posts', $posts);
    }

    public function show($slug)
    {
        $post = Entry::where('slug',$slug)->first();
        $post->increment('views');
        $tags = explode(",", $post->tags);
        $comments = $post->comments()->where('approved', 3)->get();

        $otros = Entry::where('id', '!=', $post->id)->where('status',1)->where(function ($query) use($tags) {
             for ($i = 0; $i < count($tags); $i++){
                $query->orwhere('tags', 'like',  '%' . $tags[$i] .'%');
             }      
        })->where("id", "<>", $post->id)->inRandomOrder()->take(config("blog.blog-show.otros"))->get();
        
        $categories = Category::all();

        if ($post != null) {
            if ($post->status == 2) {
                return redirect('inactivo');
            }
        } else {
            return redirect('no_existe');
        }

        return view('blog-public::single')
            ->with('post', $post)
            ->with('categories', $categories)
            ->with('comments', $comments)
            ->with('otros', $otros);
    }

    public function addComment(Request $request, $slug)
    {
        $entry = Entry::where('slug', $slug)->first();
        $comment = new CommentPost($request->all());

        $entry->comments()->save($comment);

        return redirect()
                ->back()
                ->with('comment', 'comment');
    }

}
